@@ -12,7 +12,7 @@
 
 #include <Akonadi/Item>
 
-#include <KMime/KMimeMessage>
+#include <KMime/Message>
 
 #include "messagelist_export.h"
 #include <QList>
@@ -309,7 +309,7 @@ public:
     [[nodiscard]] Akonadi::Collection currentCollection() const;
 
     void setQuickSearchClickMessage(const QString &msg);
-    MessageList::Core::QuickSearchLine::SearchOptions currentOptions() const;
+    [[nodiscard]] MessageList::Core::SearchMessageByButtons::SearchOptions currentOptions() const;
 
 protected:
     /**
