@@ -91,14 +91,14 @@ void ScamDetectionWebEngine::handleScanPage(const QVariant &result)
         // 1) detect if title has a url and title != href
         const QString title = mapVariant.value(QStringLiteral("title")).toString();
         QString href = mapVariant.value(QStringLiteral("src")).toString();
-        if (!QUrl(href).toString().contains(QLatin1String("kmail:showAuditLog"))) {
+        if (!QUrl(href).toString().contains(QLatin1StringView("kmail:showAuditLog"))) {
             href = href.toLower();
         }
         const QUrl url(href);
         if (!title.isEmpty()) {
-            if (title.startsWith(QLatin1String("http:")) || title.startsWith(QLatin1String("https:")) || title.startsWith(QLatin1String("www."))) {
-                if (title.startsWith(QLatin1String("www."))) {
-                    const QString completUrl = url.scheme() + QLatin1String("://") + title;
+            if (title.startsWith(QLatin1StringView("http:")) || title.startsWith(QLatin1StringView("https:")) || title.startsWith(QLatin1StringView("www."))) {
+                if (title.startsWith(QLatin1StringView("www."))) {
+                    const QString completUrl = url.scheme() + QLatin1StringView("://") + title;
                     if (completUrl != href && href != (completUrl + QLatin1Char('/'))) {
                         foundScam = true;
                     }
@@ -111,43 +111,43 @@ void ScamDetectionWebEngine::handleScanPage(const QVariant &result)
                     }
                 }
                 if (foundScam) {
-                    d->mDetails += QLatin1String("<li>")
+                    d->mDetails += QLatin1StringView("<li>")
                         + i18n("This email contains a link which reads as '%1' in the text, but actually points to '%2'. This is often the case in scam emails "
                                "to mislead the recipient",
                                addWarningColor(title),
                                addWarningColor(href))
-                        + QLatin1String("</li>");
+                        + QLatin1StringView("</li>");
                 }
             }
         }
         if (!foundScam) {
             // 2) detect if url href has ip and not server name.
             const QString hostname = url.host();
-            if (hostname.contains(ip4regExp) && !hostname.contains(QLatin1String("127.0.0.1"))) { // hostname
-                d->mDetails += QLatin1String("<li>")
+            if (hostname.contains(ip4regExp) && !hostname.contains(QLatin1StringView("127.0.0.1"))) { // hostname
+                d->mDetails += QLatin1StringView("<li>")
                     + i18n("This email contains a link which points to a numerical IP address (%1) instead of a typical textual website address. This is often "
                            "the case in scam emails.",
                            addWarningColor(hostname))
-                    + QLatin1String("</li>");
+                    + QLatin1StringView("</li>");
                 foundScam = true;
             } else if (hostname.contains(QLatin1Char('%'))) { // Hexa value for ip
-                d->mDetails += QLatin1String("<li>")
+                d->mDetails += QLatin1StringView("<li>")
                     + i18n("This email contains a link which points to a hexadecimal IP address (%1) instead of a typical textual website address. This is "
                            "often the case in scam emails.",
                            addWarningColor(hostname))
-                    + QLatin1String("</li>");
+                    + QLatin1StringView("</li>");
                 foundScam = true;
-            } else if (url.toString().contains(QLatin1String("url?q="))) { // 4) redirect url.
-                d->mDetails += QLatin1String("<li>") + i18n("This email contains a link (%1) which has a redirection", addWarningColor(url.toString()))
-                    + QLatin1String("</li>");
+            } else if (url.toString().contains(QLatin1StringView("url?q="))) { // 4) redirect url.
+                d->mDetails += QLatin1StringView("<li>") + i18n("This email contains a link (%1) which has a redirection", addWarningColor(url.toString()))
+                    + QLatin1StringView("</li>");
                 foundScam = true;
             } else if ((url.toString().count(QStringLiteral("http://")) > 1)
                        || (url.toString().count(QStringLiteral("https://")) > 1)) { // 5) more that 1 http in url.
-                if (!url.toString().contains(QLatin1String("kmail:showAuditLog"))) {
-                    d->mDetails += QLatin1String("<li>")
+                if (!url.toString().contains(QLatin1StringView("kmail:showAuditLog"))) {
+                    d->mDetails += QLatin1StringView("<li>")
                         + i18n("This email contains a link (%1) which contains multiple http://. This is often the case in scam emails.",
                                addWarningColor(url.toString()))
-                        + QLatin1String("</li>");
+                        + QLatin1StringView("</li>");
                     foundScam = true;
                 }
             }
@@ -155,18 +155,19 @@ void ScamDetectionWebEngine::handleScanPage(const QVariant &result)
         // Check shortUrl
         if (!foundScam) {
             if (ScamCheckShortUrl::isShortUrl(url)) {
-                d->mDetails += QLatin1String("<li>")
-                    + i18n("This email contains a shorturl (%1). It can redirect to another server.", addWarningColor(url.toString())) + QLatin1String("</li>");
+                d->mDetails += QLatin1StringView("<li>")
+                    + i18n("This email contains a shorturl (%1). It can redirect to another server.", addWarningColor(url.toString()))
+                    + QLatin1StringView("</li>");
                 foundScam = true;
             }
         }
         if (!foundScam) {
             QUrl displayUrl = QUrl(mapVariant.value(QStringLiteral("text")).toString());
             // Special case if https + port 443 it will return url without port
-            QString text = (displayUrl.port() == 443 && displayUrl.scheme() == QLatin1String("https"))
+            QString text = (displayUrl.port() == 443 && displayUrl.scheme() == QLatin1StringView("https"))
                 ? displayUrl.toDisplayString(QUrl::StripTrailingSlash | QUrl::NormalizePathSegments | QUrl::RemovePort)
                 : displayUrl.toDisplayString(QUrl::StripTrailingSlash | QUrl::NormalizePathSegments);
-            if (text.endsWith(QLatin1String("%22"))) {
+            if (text.endsWith(QLatin1StringView("%22"))) {
                 text.chop(3);
             }
             const QUrl normalizedHrefUrl = QUrl(href.toLower());
@@ -176,13 +177,13 @@ void ScamDetectionWebEngine::handleScanPage(const QVariant &result)
                     normalizedHref.replace(QStringLiteral("%5C"), QStringLiteral("/"));
                 }
             }
-            if (normalizedHref.endsWith(QLatin1String("%22"))) {
+            if (normalizedHref.endsWith(QLatin1StringView("%22"))) {
                 normalizedHref.chop(3);
             }
             // qDebug() << "text " << text << " href "<<href << " normalizedHref " << normalizedHref;
 
             if (!text.isEmpty()) {
-                if (text.startsWith(QLatin1String("http:/")) || text.startsWith(QLatin1String("https:/"))) {
+                if (text.startsWith(QLatin1StringView("http:/")) || text.startsWith(QLatin1StringView("https:/"))) {
                     if (text.toLower() != normalizedHref.toLower()) {
                         if (text != normalizedHref) {
                             if (normalizedHref != (text + QLatin1Char('/'))) {
@@ -197,13 +198,13 @@ void ScamDetectionWebEngine::handleScanPage(const QVariant &result)
                                             // qDebug() << "displayUrlWithoutQuery "  << displayUrlWithoutQuery << " hrefUrlWithoutQuery " <<
                                             // hrefUrlWithoutQuery << " text " << text;
                                             if (qurlqueryequal && (displayUrlWithoutQuery + QLatin1Char('/') != hrefUrlWithoutQuery)) {
-                                                d->mDetails += QLatin1String("<li>")
+                                                d->mDetails += QLatin1StringView("<li>")
                                                     + i18n("This email contains a link which reads as '%1' in the text, but actually points to '%2'. This is "
                                                            "often "
                                                            "the case in scam emails to mislead the recipient",
                                                            addWarningColor(text),
                                                            addWarningColor(normalizedHref))
-                                                    + QLatin1String("</li>");
+                                                    + QLatin1StringView("</li>");
                                                 foundScam = true;
                                             }
                                         }
@@ -217,12 +218,13 @@ void ScamDetectionWebEngine::handleScanPage(const QVariant &result)
         }
     }
     if (mapResult.value(QStringLiteral("forms")).toInt() > 0) {
-        d->mDetails += QLatin1String("<li></b>") + i18n("Message contains form element. This is often the case in scam emails.") + QLatin1String("</b></li>");
+        d->mDetails +=
+            QLatin1StringView("<li></b>") + i18n("Message contains form element. This is often the case in scam emails.") + QLatin1StringView("</b></li>");
         foundScam = true;
     }
     if (foundScam) {
-        d->mDetails.prepend(QLatin1String("<b>") + i18n("Details:") + QLatin1String("</b><ul>"));
-        d->mDetails += QLatin1String("</ul>");
+        d->mDetails.prepend(QLatin1StringView("<b>") + i18n("Details:") + QLatin1StringView("</b><ul>"));
+        d->mDetails += QLatin1StringView("</ul>");
         Q_EMIT messageMayBeAScam();
     }
     Q_EMIT resultScanDetection(foundScam);
